/*
   Carte : ESP8266
   Version : 03
   Integration d'une servo commande pour piloter le bras-crochet
   Author: phil
*/

#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <Servo.h>

ESP8266WebServer server(80);

#define DEBUG

#define AIA 12   // (pwm) D6 connected to pin A-IA
#define AIB 14   // (pwm) D5 connected to pin A-IB
#define BIA 0    // (pwm) D3 connected to pin B-IA
#define BIB 4    // (pwm) D2 connected to pin B-IB
#define LEDG 2   // D4 LED Gauche  
#define LEDD 13  // D7 LED Droite  

const char *ssid = "minirobo02";
const char *password = "minirobo02";

int speed = 1024; 
int etatbras = 0;

Servo bras;

void setup() {

  delay(100);

#ifdef DEBUG
  Serial.begin(115200);
  Serial.println();
  Serial.print("Configuring access point...");
#endif

  WiFi.mode(WIFI_AP);
  delay(500);
  WiFi.softAP(ssid, password);

#ifdef DEBUG
  IPAddress serverIP = WiFi.softAPIP();
  Serial.println();
  Serial.print("Server IP address: ");
  Serial.println(WiFi.softAPIP());
  Serial.print("Server MAC address: ");
  Serial.println(WiFi.softAPmacAddress());
#endif

  pinMode(AIA, OUTPUT); // set pins to output
  pinMode(AIB, OUTPUT);
  pinMode(BIA, OUTPUT);
  pinMode(BIB, OUTPUT);
  pinMode(LEDG, OUTPUT);
  pinMode(LEDD, OUTPUT);

  digitalWrite(AIA, LOW);
  digitalWrite(AIB, LOW);
  digitalWrite(BIA, LOW);
  digitalWrite(BIB, LOW);
  digitalWrite(LEDG, LOW);
  digitalWrite(LEDD, LOW);

  pinMode(D8, OUTPUT);
  digitalWrite(D8, LOW);
  
  // capitaine crochet
  bras.attach(D8);

  delay(500);
  
  //bras.write(10);
  bras.write(80); 
  etatbras = 0;

  delay(150);
  

  // set up server answers
  server.on("/wifibot/av", mot_AV);
  server.on("/wifibot/ar", mot_AR);
  server.on("/wifibot/ga", mot_GA);
  server.on("/wifibot/dr", mot_DR);
  server.on("/wifibot/stop", mot_stop);
  server.on("/wifibot/ping", ping);

  server.begin();
  
#ifdef DEBUG
  Serial.print("Server started!");
  Serial.printf("Stations connected = %d\n", WiFi.softAPgetStationNum());  
#endif
}

void loop() {

  switch (WiFi.softAPgetStationNum()) {
    case 0 :
      // Serial.printf("Pas de station connect \n");
      digitalWrite(LEDG, LOW);
      digitalWrite(LEDD, LOW);      
      delay(10);
      break;
    case 1 :
     // Serial.printf("Une station connect \n");
      digitalWrite(LEDG, !digitalRead(LEDG));
      server.handleClient();
      break;
    case 2 :
      Serial.printf("deux station connect \n");
      digitalWrite(LEDD, !digitalRead(LEDD));
      setMotor(0, 0, 0, 0); 
      delay(10);
      break;
  }
}

void mot_stop() {

  server.send(200, "text/plain", "STOP" );
 // setMotor(0, 0, 0, 0); 
  if ( etatbras == 0  ) {
    bras.write(80);    
    //bras.write(10);
    etatbras = 1;
   Serial.println("ETAT 0");
  }
  else {
    bras.write(40);
    //bras.write(80);
    etatbras = 0;
   Serial.println("ETAT 1");   
  }  
   
#ifdef DEBUG
   Serial.println("STOP!!");
#endif
}

void ping() {
  server.send(200, "text/plain", "ok" );
#ifdef DEBUG
  Serial.println("PING !");
#endif
}

void mot_GA() {
  server.send(200, "text/plain", "A gauche" );
  setMotor(0, speed, speed, 0);
#ifdef DEBUG
  Serial.println("A gauche");
#endif
}

void mot_DR() {
  server.send(200, "text/plain", "A droite" );
  setMotor(speed, 0, 0, speed);
#ifdef DEBUG
  Serial.println("A droite");
#endif
}

void mot_AR() {
  server.send(200, "text/plain", "En arriere" );
  setMotor(speed, 0, speed, 0);
#ifdef DEBUG
  Serial.println("En arriere ");
#endif
}

void mot_AV() {
  server.send(200, "text/plain", "En avant" );
  setMotor(0, speed, 0, speed);
#ifdef DEBUG
  Serial.println("En avant");
#endif
}

void setMotor(int vAIA, int vAIB, int vBIA, int vBIB) {
  analogWrite(AIA, vAIA);
  analogWrite(AIB, vAIB);
  analogWrite(BIA, vBIA);
  analogWrite(BIB, vBIB);
  delay(100);
  analogWrite(AIA, 0);
  analogWrite(AIB, 0);
  analogWrite(BIA, 0);
  analogWrite(BIB, 0);  
}

